# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAuditResponse(Model):
    """BillAuditResponse.

    :param auditor_id:
    :type auditor_id: int
    :param auditor_code:
    :type auditor_code: str
    :param auditor_info:
    :type auditor_info: str
    :param description:
    :type description: str
    :param audit_category:
    :type audit_category: ~energycap.sdk.models.AuditCategory
    :param recommended:
    :type recommended: bool
    :param alert_severity:
    :type alert_severity: ~energycap.sdk.models.AlertSeverityResponse
    :param skip_zero_comparison_option:
    :type skip_zero_comparison_option: bool
    :param properties:
    :type properties: list[~energycap.sdk.models.AuditProperty]
    """

    _attribute_map = {
        'auditor_id': {'key': 'auditorId', 'type': 'int'},
        'auditor_code': {'key': 'auditorCode', 'type': 'str'},
        'auditor_info': {'key': 'auditorInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'audit_category': {'key': 'auditCategory', 'type': 'AuditCategory'},
        'recommended': {'key': 'recommended', 'type': 'bool'},
        'alert_severity': {'key': 'alertSeverity', 'type': 'AlertSeverityResponse'},
        'skip_zero_comparison_option': {'key': 'skipZeroComparisonOption', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '[AuditProperty]'},
    }

    def __init__(self, auditor_id=None, auditor_code=None, auditor_info=None, description=None, audit_category=None, recommended=None, alert_severity=None, skip_zero_comparison_option=None, properties=None):
        super(BillAuditResponse, self).__init__()
        self.auditor_id = auditor_id
        self.auditor_code = auditor_code
        self.auditor_info = auditor_info
        self.description = description
        self.audit_category = audit_category
        self.recommended = recommended
        self.alert_severity = alert_severity
        self.skip_zero_comparison_option = skip_zero_comparison_option
        self.properties = properties
