# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PerformanceComparison(Model):
    """PerformanceComparison.

    :param id:
    :type id: int
    :param label:
    :type label: str
    :param cy_cost:
    :type cy_cost: float
    :param py_cost:
    :type py_cost: float
    :param cost_display:
    :type cost_display: str
    :param cost_percent_diff:
    :type cost_percent_diff: float
    :param use_percent_diff:
    :type use_percent_diff: float
    :param third_value_display:
    :type third_value_display: str
    :param third_value_percent_diff:
    :type third_value_percent_diff: float
    :param cy_display:
    :type cy_display: str
    :param py_display:
    :type py_display: str
    :param cy_global_use:
    :type cy_global_use: float
    :param py_global_use:
    :type py_global_use: float
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'label': {'key': 'label', 'type': 'str'},
        'cy_cost': {'key': 'cyCost', 'type': 'float'},
        'py_cost': {'key': 'pyCost', 'type': 'float'},
        'cost_display': {'key': 'costDisplay', 'type': 'str'},
        'cost_percent_diff': {'key': 'costPercentDiff', 'type': 'float'},
        'use_percent_diff': {'key': 'usePercentDiff', 'type': 'float'},
        'third_value_display': {'key': 'thirdValueDisplay', 'type': 'str'},
        'third_value_percent_diff': {'key': 'thirdValuePercentDiff', 'type': 'float'},
        'cy_display': {'key': 'cyDisplay', 'type': 'str'},
        'py_display': {'key': 'pyDisplay', 'type': 'str'},
        'cy_global_use': {'key': 'cyGlobalUse', 'type': 'float'},
        'py_global_use': {'key': 'pyGlobalUse', 'type': 'float'},
    }

    def __init__(self, id=None, label=None, cy_cost=None, py_cost=None, cost_display=None, cost_percent_diff=None, use_percent_diff=None, third_value_display=None, third_value_percent_diff=None, cy_display=None, py_display=None, cy_global_use=None, py_global_use=None):
        super(PerformanceComparison, self).__init__()
        self.id = id
        self.label = label
        self.cy_cost = cy_cost
        self.py_cost = py_cost
        self.cost_display = cost_display
        self.cost_percent_diff = cost_percent_diff
        self.use_percent_diff = use_percent_diff
        self.third_value_display = third_value_display
        self.third_value_percent_diff = third_value_percent_diff
        self.cy_display = cy_display
        self.py_display = py_display
        self.cy_global_use = cy_global_use
        self.py_global_use = py_global_use
