# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProcessAudits(Model):
    """ProcessAudits.

    :param audit_group_ids:  <span class='property-internal'>Required</span>
     <span class='property-internal'>Cannot be Empty</span>
    :type audit_group_ids: list[int]
    :param filters:  <span class='property-internal'>Required</span>
    :type filters: list[~energycap.sdk.models.FilterEdit]
    :param use_stored_filters:  <span
     class='property-internal'>Required</span>
    :type use_stored_filters: bool
    """

    _validation = {
        'audit_group_ids': {'required': True},
        'filters': {'required': True},
        'use_stored_filters': {'required': True},
    }

    _attribute_map = {
        'audit_group_ids': {'key': 'auditGroupIds', 'type': '[int]'},
        'filters': {'key': 'filters', 'type': '[FilterEdit]'},
        'use_stored_filters': {'key': 'useStoredFilters', 'type': 'bool'},
    }

    def __init__(self, audit_group_ids, filters, use_stored_filters):
        super(ProcessAudits, self).__init__()
        self.audit_group_ids = audit_group_ids
        self.filters = filters
        self.use_stored_filters = use_stored_filters
