# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DestinationAccountResponse(Model):
    """DestinationAccountResponse.

    :param account_id: The account identifier
    :type account_id: int
    :param account_code: The account code
    :type account_code: str
    :param account_info: The account info
    :type account_info: str
    :param vendor: The account's vendor
    :type vendor: ~energycap.sdk.models.VendorChild
    :param meters: An array of identifiers for meters attached to this account
    :type meters: list[~energycap.sdk.models.DestinationAccountMeterChild]
    """

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'vendor': {'key': 'vendor', 'type': 'VendorChild'},
        'meters': {'key': 'meters', 'type': '[DestinationAccountMeterChild]'},
    }

    def __init__(self, account_id=None, account_code=None, account_info=None, vendor=None, meters=None):
        super(DestinationAccountResponse, self).__init__()
        self.account_id = account_id
        self.account_code = account_code
        self.account_info = account_info
        self.vendor = vendor
        self.meters = meters
