# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificAuditWithAuditGroup(Model):
    """SpecificAuditWithAuditGroup.

    :param audit_group:
    :type audit_group: ~energycap.sdk.models.BillAuditGroupChild
    :param specific_audit_id:
    :type specific_audit_id: int
    :param specific_audit_info:
    :type specific_audit_info: str
    :param auditor_id:
    :type auditor_id: int
    :param auditor_code:
    :type auditor_code: str
    :param description:
    :type description: str
    """

    _attribute_map = {
        'audit_group': {'key': 'auditGroup', 'type': 'BillAuditGroupChild'},
        'specific_audit_id': {'key': 'specificAuditId', 'type': 'int'},
        'specific_audit_info': {'key': 'specificAuditInfo', 'type': 'str'},
        'auditor_id': {'key': 'auditorId', 'type': 'int'},
        'auditor_code': {'key': 'auditorCode', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, audit_group=None, specific_audit_id=None, specific_audit_info=None, auditor_id=None, auditor_code=None, description=None):
        super(SpecificAuditWithAuditGroup, self).__init__()
        self.audit_group = audit_group
        self.specific_audit_id = specific_audit_id
        self.specific_audit_info = specific_audit_info
        self.auditor_id = auditor_id
        self.auditor_code = auditor_code
        self.description = description
