# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PerformanceComparisonDataResponse(Model):
    """PerformanceComparisonDataResponse.

    :param data_points:
    :type data_points:
     list[~energycap.sdk.models.PerformanceComparisonDataPoint]
    :param performance_comparisons:
    :type performance_comparisons:
     list[~energycap.sdk.models.PerformanceComparison]
    """

    _attribute_map = {
        'data_points': {'key': 'dataPoints', 'type': '[PerformanceComparisonDataPoint]'},
        'performance_comparisons': {'key': 'performanceComparisons', 'type': '[PerformanceComparison]'},
    }

    def __init__(self, data_points=None, performance_comparisons=None):
        super(PerformanceComparisonDataResponse, self).__init__()
        self.data_points = data_points
        self.performance_comparisons = performance_comparisons
