# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AlertStatusResponse(Model):
    """AlertStatusResponse.

    :param alert_status_id:
    :type alert_status_id: int
    :param alert_status_info:
    :type alert_status_info: str
    """

    _attribute_map = {
        'alert_status_id': {'key': 'alertStatusId', 'type': 'int'},
        'alert_status_info': {'key': 'alertStatusInfo', 'type': 'str'},
    }

    def __init__(self, alert_status_id=None, alert_status_info=None):
        super(AlertStatusResponse, self).__init__()
        self.alert_status_id = alert_status_id
        self.alert_status_info = alert_status_info
