# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillImportProfileResponse(Model):
    """BillImportProfileResponse.

    :param profile_id:
    :type profile_id: int
    :param profile_code:  <span class='property-internal'>Required</span>
     <span class='property-internal'>Must be between 0 and 64 characters</span>
     <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type profile_code: str
    :param column_mapping:
    :type column_mapping: ~energycap.sdk.models.BillImportProfileColumnMapping
    """

    _validation = {
        'profile_code': {'required': True, 'max_length': 64, 'min_length': 0},
    }

    _attribute_map = {
        'profile_id': {'key': 'profileId', 'type': 'int'},
        'profile_code': {'key': 'profileCode', 'type': 'str'},
        'column_mapping': {'key': 'columnMapping', 'type': 'BillImportProfileColumnMapping'},
    }

    def __init__(self, profile_code, profile_id=None, column_mapping=None):
        super(BillImportProfileResponse, self).__init__()
        self.profile_id = profile_id
        self.profile_code = profile_code
        self.column_mapping = column_mapping
