# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MonthlyCAPTrend(Model):
    """MonthlyCAPTrend.

    :param actual_cost:
    :type actual_cost: float
    :param cap_cost:
    :type cap_cost: float
    :param avoided_cost:
    :type avoided_cost: float
    :param percent_cost:
    :type percent_cost: float
    :param actual_use:
    :type actual_use: float
    :param cap_use:
    :type cap_use: float
    :param avoided_use:
    :type avoided_use: float
    :param percent_use:
    :type percent_use: float
    :param billing_period:
    :type billing_period: int
    """

    _attribute_map = {
        'actual_cost': {'key': 'actualCost', 'type': 'float'},
        'cap_cost': {'key': 'capCost', 'type': 'float'},
        'avoided_cost': {'key': 'avoidedCost', 'type': 'float'},
        'percent_cost': {'key': 'percentCost', 'type': 'float'},
        'actual_use': {'key': 'actualUse', 'type': 'float'},
        'cap_use': {'key': 'capUse', 'type': 'float'},
        'avoided_use': {'key': 'avoidedUse', 'type': 'float'},
        'percent_use': {'key': 'percentUse', 'type': 'float'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
    }

    def __init__(self, actual_cost=None, cap_cost=None, avoided_cost=None, percent_cost=None, actual_use=None, cap_use=None, avoided_use=None, percent_use=None, billing_period=None):
        super(MonthlyCAPTrend, self).__init__()
        self.actual_cost = actual_cost
        self.cap_cost = cap_cost
        self.avoided_cost = avoided_cost
        self.percent_cost = percent_cost
        self.actual_use = actual_use
        self.cap_use = cap_use
        self.avoided_use = avoided_use
        self.percent_use = percent_use
        self.billing_period = billing_period
