# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PerformanceComparisonDataPoint(Model):
    """PerformanceComparisonDataPoint.

    :param period_number:
    :type period_number: int
    :param id:
    :type id: int
    :param cy_use:
    :type cy_use: float
    :param py_use:
    :type py_use: float
    :param cy_global_use:
    :type cy_global_use: float
    :param py_global_use:
    :type py_global_use: float
    """

    _attribute_map = {
        'period_number': {'key': 'periodNumber', 'type': 'int'},
        'id': {'key': 'id', 'type': 'int'},
        'cy_use': {'key': 'cyUse', 'type': 'float'},
        'py_use': {'key': 'pyUse', 'type': 'float'},
        'cy_global_use': {'key': 'cyGlobalUse', 'type': 'float'},
        'py_global_use': {'key': 'pyGlobalUse', 'type': 'float'},
    }

    def __init__(self, period_number=None, id=None, cy_use=None, py_use=None, cy_global_use=None, py_global_use=None):
        super(PerformanceComparisonDataPoint, self).__init__()
        self.period_number = period_number
        self.id = id
        self.cy_use = cy_use
        self.py_use = py_use
        self.cy_global_use = cy_global_use
        self.py_global_use = py_global_use
