# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillUnexportOptions(Model):
    """BillUnexportOptions.

    :param export_mode:  <span class='property-internal'>Required</span> <span
     class='property-internal'>One of ap, gl </span>
    :type export_mode: str
    """

    _validation = {
        'export_mode': {'required': True},
    }

    _attribute_map = {
        'export_mode': {'key': 'exportMode', 'type': 'str'},
    }

    def __init__(self, export_mode):
        super(BillUnexportOptions, self).__init__()
        self.export_mode = export_mode
