# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FixedDemandRequest(Model):
    """FixedDemandRequest.

    :param fixed_demand_amount: Fixed demand amount <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     precision of 6</span>
    :type fixed_demand_amount: float
    :param unit_id: Unit to which demand is applied <span
     class='property-internal'>Required</span>
    :type unit_id: int
    """

    _validation = {
        'fixed_demand_amount': {'required': True},
        'unit_id': {'required': True},
    }

    _attribute_map = {
        'fixed_demand_amount': {'key': 'fixedDemandAmount', 'type': 'float'},
        'unit_id': {'key': 'unitId', 'type': 'int'},
    }

    def __init__(self, fixed_demand_amount, unit_id):
        super(FixedDemandRequest, self).__init__()
        self.fixed_demand_amount = fixed_demand_amount
        self.unit_id = unit_id
